@@ -9,10 +9,9 @@
 """
 from ._settings import Settings
 from ._listener import Listener
-from ._controller import Controller
 from ._processor import SignalProcessor
 
 __project__ = 'pi-clap'
-__version__ = '1.2.1'
+__version__ = '1.3'
 __author__ = 'Nikhil John'
-__all__ = ['Settings', 'Listener', 'Controller', 'SignalProcessor']
+__all__ = ['Settings', 'Listener', 'SignalProcessor']
